Structs
- Clue
LyDetection Result - Detailed detection result with evasion techniques
Functions
- detect_
cluely - C API - Main detection function (for compatibility)
- detect_
cluely_ rust - Main detection function - returns detailed result This is the primary Rust API for detection
- free_
cluely_ ⚠report - Free memory allocated by get_cluely_report
- get_
cluely_ report - Generate a detailed text report of Cluely detection Returns a pointer to a C string that must be freed with free_cluely_report
- get_
cluely_ window_ count - C API - Get window count (for compatibility)
- get_
cluely_ window_ count_ rust - Get the number of Cluely windows detected (Rust API)
- is_
cluely_ running - C API - Simple boolean check (for compatibility)
- is_
cluely_ running_ rust - Simple boolean check function for Rust API